@@ -11,8 +11,8 @@
 # -----------------------------------------------------------------------------
 
 import sys, os
-sys.path.append(os.path.dirname(os.path.abspath('../../../shared/versions.py')))
-from versions import *
+sys.path.append(os.path.dirname(os.path.abspath('../../../shared/sundials_vars.py')))
+from sundials_vars import *
 sys.path.append(os.path.dirname(os.path.abspath('../../../shared')))
 
 # -- General configuration ----------------------------------------------------
@@ -26,10 +26,14 @@ needs_sphinx = '4.0'
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx_rtd_theme', 'sphinx.ext.ifconfig', 'sphinx.ext.mathjax',
+extensions = ['sphinx_rtd_theme', 'sphinx.ext.ifconfig',
+              'sphinx.ext.intersphinx', 'sphinx.ext.mathjax',
               'sphinxfortran.fortran_domain', 'sphinxcontrib.bibtex',
               'sphinx_copybutton', 'sphinx_sundials']
 
+intersphinx_mapping = {'sundials': (f'https://sundials.readthedocs.io/en/{doc_version}',
+                                    ('../../../superbuild/build/html/objects.inv', None))}
+
 # References
 bibtex_bibfiles = ['../../../shared/sundials.bib']
 
@@ -286,7 +290,7 @@ man_pages = [
 texinfo_documents = [
   ('index', 'ARKODE', u'ARKODE Documentation',
    u'Daniel R. Reynolds, David J. Gardner, Carol S. Woodward, Rujeko Chinomona, and Cody J. Balos', 'ARKODE',
-   'Time integration package for multi-rate systems of ordinary differntial equations.',
+   'Time integration package for multi-rate systems of ordinary differential equations.',
    'Miscellaneous'),
 ]
 
